seqtools.partition_sequence_cyclically_by_weights_at_least_with_overhang
========================================================================

.. autofunction:: abjad.tools.seqtools.partition_sequence_cyclically_by_weights_at_least_with_overhang
